tlslite.messages.ServerHello

Package tlslite :: Module messages :: Class ServerHello |
[hide private]
[frames] | no frames]

# Class ServerHello

source code

    HandshakeMsg --+
                   |
                  ServerHello

Instance Methods | [hide private]
__init__(self) | source code
__next_protos_encoded(self) | source code
__parse_next_protos(self, b) | source code
create(self, version, random, session_id, cipher_suite, certificate_type, tackExt, next_protos_advertised) | source code
parse(self, p) | source code
write(self) | source code
Inherited from `HandshakeMsg`: `postWrite`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
Overrides: HandshakeMsg.__init__